@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Dancer2::Plugin;
-$Dancer2::Plugin::Locale::VERSION = '0.04';
+$Dancer2::Plugin::Locale::VERSION = '0.05';
 
 package Dancer2::Plugin::Locale::Obj;
 use Locales 0.33 unicode => 1;
@@ -18,21 +18,22 @@ use File::Spec;
 
 # use Tie::Hash::ReadonlyStack;
 
-register locale => sub {
+plugin_keywords 'locale';
+
+sub locale {
     my $dsl = shift;
 
     if (@_) {
         return Dancer2::Plugin::Locale::Obj->get_handle( grep( { defined } (@_) ), 'en' );    # multiton already via Locale::Maketext::Utils
     }
 
-    my $conf = plugin_setting();
     my $app  = $dsl->app;
 
     # TODO 2: request locale via browser/HTP req after session and before default?
-    return Dancer2::Plugin::Locale::Obj->get_handle( grep( { defined } ( eval { $app->session->read('locale') }, $conf->{default_locale} ) ), 'en' );    # multiton already via Locale::Maketext::Utils
+    return Dancer2::Plugin::Locale::Obj->get_handle( grep( { defined } ( eval { $app->session->read('locale') }, $dsl->config->{default_locale} ) ), 'en' );    # multiton already via Locale::Maketext::Utils
 };
 
-on_plugin_import {
+sub BUILD {
     my $dsl = shift;
 
     my @available_locales = ('en');
@@ -100,8 +101,6 @@ sub _from_json_file {
 # TODO 2: localization tips
 # TODO 2: extractor/checker tool
 
-register_plugin;
-
 1;
 
 __END__
@@ -114,7 +113,7 @@ Dancer2::Plugin::Locale - Localize your Dancer2 application
 
 =head1 VERSION
 
-This document describes Dancer2::Plugin::Locale version 0.04
+This document describes Dancer2::Plugin::Locale version 0.05
 
 =head1 SYNOPSIS
 
